#! /usr/bin/env python
# -*- coding: iso-8859-1 -*-
"""%prog [options] arg

Takes a file written for Simply Draw and generates the eps
graphic file.

Copyright (C) 2005 by Armin Straub <linux@arminstraub.de>
"""

"""
This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.
"""

def main():
    """Main program (invoked automatically, when executed)"""
    from optparse import OptionParser
    import simplydraw
    parser = OptionParser(__doc__, version=simplydraw.__version__)

    parser.add_option("-o", "--output", type="string", default="",
            help="output to FILE.eps", metavar="FILE")
    parser.add_option("-q", "--quiet", action="store_true", default=False)

    (options, args) = parser.parse_args()

    if len(args) == 0:
        parser.error("you need to specify at least one argument")
    elif options.output and len(args) != 1:
        parser.error("you can only use one argument when specifying an output file")

    for file in args:
        if options.output:
            output = options.output
        else:
            import os
            output = os.path.splitext(file)[0]

        if not options.quiet:
            print "Generating %s.eps ..." % (output),

        writeEPS(file, output)

        if not options.quiet:
            print "done."


# If available import numarray as well (which turns
# out to be useful when drawing mathematical objects).
try:
    from numarray import *
    from numarray.random_array import *
except ImportError:
    pass

from simplydraw import *

def writeEPS(file, output):
    # Let the given file paint itself. These parameters
    # ensure that functions in that file can access
    # variables defined outside that function but still
    # in the file.
    execfile(file, globals(), globals())
    # Scale the graphic if requested.
    if getscale() != (1, 1):
        c = canvas()
        c.insert(getcanvas(), [scale(*getscale())])
    else:
        c = getcanvas()
    c.writeEPSfile(output)
    setcanvas(None)


if __name__ == "__main__":
    main()
