#! /usr/bin/env python
# -*- coding: iso-8859-1 -*-
"""
Simply Draw for Python.
See arminstraub.de for more information.

Copyright (C) 2005 by Armin Straub <linux@arminstraub.de>
"""

"""
This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.
"""

from simplydraw import canvas, clip


# Keep a global canvas object in background. Its methods
# as insert() can be used without the self parameter.

_canvas = None

def getcanvas():
    """Returns the global canvas.
    
    Should be rarely needed."""
    global _canvas
    if _canvas == None:
        _canvas = canvas()
    return _canvas

def setcanvas(c):
    """Sets the global canvas.
    
    Should be rarely needed."""
    global _canvas
    _canvas = c

def bbox(*args, **kwargs):
    return getcanvas().bbox(*args, **kwargs)
def draw(*args, **kwargs):
    return getcanvas().draw(*args, **kwargs)
def stroke(*args, **kwargs):
    return getcanvas().stroke(*args, **kwargs)
def fill(*args, **kwargs):
    return getcanvas().fill(*args, **kwargs)
def text(*args, **kwargs):
    return getcanvas().text(*args, **kwargs)
def insert(*args, **kwargs):
    return getcanvas().insert(*args, **kwargs)
def point(*args, **kwargs):
    return getcanvas().point(*args, **kwargs)
def label(*args, **kwargs):
    return getcanvas().label(*args, **kwargs)
def stack(*args, **kwargs):
    return getcanvas().stack(*args, **kwargs)


# Global scale factor. It's set via the set() function.

_scale = (1, 1)

def getscale():
    """Returns the global scale factor.
    
    Should be rarely needed."""
    global _scale
    return _scale


# Setting global parameters

def set(**kwargs):
    """Set global parameters like clipping and scaling.
    
    Currently you can set here via scale, xscale and yscale
    a global scale factor. These scale factors will be
    accumulated.
    Using clip as an argument you can clip the global canvas
    to a given path. This will utilize the clip() function
    you can use when constructing a canvas."""
    global _scale, _canvas
    for (arg, value) in kwargs.items():
        if arg == 'scale':
            _scale = (value * _scale[0], value * _scale[1])
        elif arg == 'xscale':
            _scale = (value * _scale[0], _scale[1])
        elif arg == 'yscale':
            _scale = (_scale[0], value * _scale[1])
        elif arg == 'clip':
            c = canvas([clip(value)])
            if _canvas != None:
                c.insert(_canvas)
            _canvas = c
